@@ -1,7 +1,7 @@
 package Data::Unixish::subsort;
 
 our $DATE = '2019-10-26'; # DATE
-our $VERSION = '1.571'; # VERSION
+our $VERSION = '1.572'; # VERSION
 
 use 5.010;
 use strict;
@@ -24,6 +24,11 @@ $SPEC{subsort} = {
             req => 1,
             pos => 0,
         },
+        routine_args => {
+            summary => 'Pass arguments for Sort::Sub routine',
+            schema=>['hash*', of=>'str*'],
+            cmdline_aliases => {a=>{}},
+        },
         reverse => {
             summary => 'Whether to reverse sort result',
             schema=>[bool => {default=>0}],
@@ -41,6 +46,7 @@ sub subsort {
     my %args = @_;
     my ($in, $out) = ($args{in}, $args{out});
     my $routine = $args{routine} or return [400, "Please specify routine"];
+    my $routine_args = $args{routine_args} // {};
     my $reverse = $args{reverse};
     my $ci      = $args{ci};
 
@@ -55,7 +61,7 @@ sub subsort {
 
     require "Sort/Sub/$routine.pm";
     my $gen_sorter = \&{"Sort::Sub::$routine\::gen_sorter"};
-    my $sorter = $gen_sorter->($reverse, $ci);
+    my $sorter = $gen_sorter->($reverse, $ci, $routine_args);
 
     @buf = sort {$sorter->($a, $b)} @buf;
 
@@ -79,7 +85,7 @@ Data::Unixish::subsort - Sort items using Sort::Sub routine
 
 =head1 VERSION
 
-This document describes version 1.571 of Data::Unixish::subsort (from Perl distribution Data-Unixish), released on 2019-10-26.
+This document describes version 1.572 of Data::Unixish::subsort (from Perl distribution Data-Unixish), released on 2019-10-26.
 
 =head1 SYNOPSIS
 
@@ -96,6 +102,12 @@ In command line:
  t2
  t10
 
+ % echo -e 'a::\nb:\nc::::\nd:::' | dux subsort by_count -a pattern=:
+ b:
+ a::
+ d:::
+ c::::
+
 =head1 FUNCTIONS
 
 
@@ -133,6 +145,10 @@ Whether to reverse sort result.
 
 Sort::Sub routine name.
 
+=item * B<routine_args> => I<hash>
+
+Pass arguments for Sort::Sub routine.
+
 =back
 
 Returns an enveloped result (an array).
